@@ -4,7 +4,7 @@ package LWPx::UserAgent::Cached;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.006';     # VERSION
+our $VERSION = '0.007';     # VERSION
 use utf8;
 
 ## no critic (Bangs::ProhibitCommentedOutCode)
@@ -24,9 +24,10 @@ use utf8;
 #pod =head1 DESCRIPTION
 #pod
 #pod This module borrows the caching logic from
-#pod L<WWW::Mechanize::Cached|WWW::Mechanize::Cached> but without
-#pod inheriting from L<WWW::Mechanize|WWW::Mechanize>;
-#pod instead it is just a direct subclass of
+#pod L<WWW::Mechanize::Cached|WWW::Mechanize::Cached> but
+#pod without inheriting from
+#pod L<WWW::Mechanize|WWW::Mechanize>; instead it is just
+#pod a direct subclass of
 #pod L<LWP::UserAgent|LWP::UserAgent>.
 #pod
 #pod =head2 HTTP/1.1 cache operation
@@ -63,10 +64,10 @@ extends 'LWP::UserAgent';
 #pod =attr cache
 #pod
 #pod Settable at construction, defaults to using
-#pod L<CHI::Driver::RawMemory|CHI::Driver::RawMemory> with an
-#pod instance-specific hash datastore and a namespace with the current package name.
-#pod You can use your own caching object here as long as it has C<get> and
-#pod C<set> methods.
+#pod L<CHI::Driver::RawMemory|CHI::Driver::RawMemory> with
+#pod an instance-specific hash datastore and a namespace with the current
+#pod package name. You can use your own caching object here as long as it has
+#pod C<get> and C<set> methods.
 #pod
 #pod =cut
 
@@ -146,10 +147,11 @@ has positive_cache => ( is => 'rw', isa => Bool, default => 1 );
 
 #pod =head1 HANDLERS
 #pod
-#pod This module works by adding C<request_send> and C<response_done>
-#pod L<handlers|LWP::UserAgent/Handlers> method that run on successful
-#pod HTTP C<GET> requests. If you need to modify or remove these handlers you may
-#pod use L<LWP::UserAgent's C<handlers>|LWP::UserAgent/Handlers> method.
+#pod This module works by adding C<request_send>, C<response_done> and
+#pod C<response_header> L<handlers|LWP::UserAgent/Handlers>
+#pod that run on successful HTTP C<GET> requests.
+#pod If you need to modify or remove these handlers you may use LWP::UserAgent's
+#pod L<handler-related methods|LWP::UserAgent/Handlers>.
 #pod
 #pod =for Pod::Coverage BUILD
 #pod
@@ -279,7 +281,7 @@ LWPx::UserAgent::Cached - Subclass of LWP::UserAgent that caches HTTP GET reques
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -296,9 +298,10 @@ version 0.006
 =head1 DESCRIPTION
 
 This module borrows the caching logic from
-L<WWW::Mechanize::Cached|WWW::Mechanize::Cached> but without
-inheriting from L<WWW::Mechanize|WWW::Mechanize>;
-instead it is just a direct subclass of
+L<WWW::Mechanize::Cached|WWW::Mechanize::Cached> but
+without inheriting from
+L<WWW::Mechanize|WWW::Mechanize>; instead it is just
+a direct subclass of
 L<LWP::UserAgent|LWP::UserAgent>.
 
 =head2 HTTP/1.1 cache operation
@@ -313,10 +316,10 @@ response) and the C<Pragma: no-cache> request header.
 =head2 cache
 
 Settable at construction, defaults to using
-L<CHI::Driver::RawMemory|CHI::Driver::RawMemory> with an
-instance-specific hash datastore and a namespace with the current package name.
-You can use your own caching object here as long as it has C<get> and
-C<set> methods.
+L<CHI::Driver::RawMemory|CHI::Driver::RawMemory> with
+an instance-specific hash datastore and a namespace with the current
+package name. You can use your own caching object here as long as it has
+C<get> and C<set> methods.
 
 =head2 is_cached
 
@@ -367,10 +370,11 @@ Inspiration for this class.
 
 =head1 HANDLERS
 
-This module works by adding C<request_send> and C<response_done>
-L<handlers|LWP::UserAgent/Handlers> method that run on successful
-HTTP C<GET> requests. If you need to modify or remove these handlers you may
-use L<LWP::UserAgent's C<handlers>|LWP::UserAgent/Handlers> method.
+This module works by adding C<request_send>, C<response_done> and
+C<response_header> L<handlers|LWP::UserAgent/Handlers>
+that run on successful HTTP C<GET> requests.
+If you need to modify or remove these handlers you may use LWP::UserAgent's
+L<handler-related methods|LWP::UserAgent/Handlers>.
 
 =for Pod::Coverage BUILD
 
